#
# spec file for package kf6-purpose
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports
%global __requires_exclude qt6qmlimport\\((org\\.kde\\.purpose|org\\.kde\\.kdeconnect|SSO\\.OnlineAccounts).*

%define qt6_version 6.8.0

%define rname purpose
# Full KF6 version (e.g. 6.15.0)
%{!?_kf6_version: %global _kf6_version %{version}}
%bcond_without released
Name:           kf6-purpose
Version:        6.15.0
Release:        1.1
Summary:        Framework to integrate services and actions in applications
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_version}
BuildRequires:  cmake(KAccounts6)
BuildRequires:  cmake(KF6Config) >= %{_kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{_kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{_kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{_kf6_version}
BuildRequires:  cmake(KF6Service) >= %{_kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       accounts-qml-module
Requires:       kf6-kdeclarative-imports >= %{_kf6_version}
Requires:       kf6-kirigami-imports >= %{_kf6_version}
Requires:       kf6-prison-imports >= %{_kf6_version}
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       purpose-services >= %{version}

%description
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

%package services
Summary:        Online services for purpose
Provides:       purpose-services = %{version}
Obsoletes:      purpose-services < %{version}

%description services
This package adds online services to kf6-purpose and are needed to connect to
Google and Nextcloud servers.

%package -n libKF6Purpose6
Summary:        Framework to integrate services and actions - core library
Requires:       kf6-purpose >= %{version}

%description -n libKF6Purpose6
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

This package contains the core library files of the package.

%package -n libKF6PurposeWidgets6
Summary:        Framework to integrate services and actions - GUI library
Recommends:     kf6-purpose >= %{version}

%description -n libKF6PurposeWidgets6
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

This package contains the library files of the package needed to use GUI widgets.

%package devel
Summary:        Framework to integrate services and actions - Build Environment
Requires:       libKF6Purpose6 = %{version}
Requires:       libKF6PurposeWidgets6 = %{version}
Requires:       cmake(KF6CoreAddons) >= %{_kf6_version}

%description devel
This package contains development files needed to build applications which rely on the purpose framework.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%define _lto_cflags %{nil}

%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang kf6-purpose --all-name

%ldconfig_scriptlets -n libKF6Purpose6
%ldconfig_scriptlets -n libKF6PurposeWidgets6

%files -n libKF6Purpose6
%{_kf6_libdir}/libKF6Purpose.so.*

%files -n libKF6PurposeWidgets6
%{_kf6_libdir}/libKF6PurposeWidgets.so.*

%files
%license LICENSES/*
%doc README.md
%{_kf6_datadir}/purpose/
%{_kf6_debugdir}/purpose.categories
%{_kf6_debugdir}/purpose.renamecategories
%{_kf6_iconsdir}/hicolor/*/apps/phabricator-purpose6.png
%{_kf6_iconsdir}/hicolor/*/apps/reviewboard-purpose6.png
%{_kf6_libexecdir}/purposeprocess
%{_kf6_plugindir}/kf6/kfileitemaction/
%{_kf6_plugindir}/kf6/purpose/
%{_kf6_qmldir}/org/kde/purpose/

%files services
%dir %{_kf6_sharedir}/accounts
%dir %{_kf6_sharedir}/accounts/services
%dir %{_kf6_sharedir}/accounts/services/kde
%{_kf6_sharedir}/accounts/services/kde/google-youtube.service
%{_kf6_sharedir}/accounts/services/kde/nextcloud-upload.service

%files devel
%{_kf6_cmakedir}/KF6Purpose/
%{_kf6_includedir}/Purpose/
%{_kf6_includedir}/PurposeWidgets/
%{_kf6_libdir}/libKF6Purpose.so
%{_kf6_libdir}/libKF6PurposeWidgets.so

%files lang -f kf6-purpose.lang

%changelog
* Mon Jun  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.15.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.15.0
- Changes since 6.14.0:
  * Use correct qdoc include
  * Update dependency version to 6.15.0
  * Add tags file to documentation
  * Add missing qhp projects
  * Add landing page for QDoc
  * Exclude dirs from main documentation module
  * It compiles fine without kf_6_13 deprecated methods
  * Port API documentation to QDoc syntax
  * Update version to 6.15.0
- Replace _kf6_bugfix_version usage
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * Update version to 6.14.0
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * It compiles fine without qt6.9 deprecated methods
  * AlternativesModel: Always reset model when initializing
  * It compiles fine without kf6.12 deprecated methods
  * Clipboard: Set clipboard text, too, if applicable
  * JobDialog: Cancel when closing window
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * plugins: make name and actiondisplay more consistent
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * youtube: Use a better fitting icon
  * Drop the Twitter plugin
  * Change both KDE Connect plugins to use symbolic versions of their icons
  * Add xml/yaml linting
  * CI: Add linux-qt6-next build
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Use DBus instead of kdeconnect-cli executable
  * [kdeconnect] Port away from org.kde.kdeconnect QML import
  * AlternativesModel: Return early if there's no input data
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * [imgur] Improve error reporting
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * clipboard: Also allow to export to the clipboard (kde#477553)
  * Introduce a clipboard plugin
  * AlternativesModel: Don't filter by fields that don't pertain to the current plugintype
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * [imgur] Restrict to actually supported MIME types
  * Add extraJsonTranslationPaths.txt file for purpose specific translations
  * Ensure KPlugin object contains no unstandardized keys
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Fix sharing via menu a second time (kde#490579)
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * JobView: Fix switch-case: add default branch
  * plugins/barcode: Fix up QML
  * widgets: Rework type registration and property initialization, improve QML
  * Don't let the Heading overflow
  * AlternativesModel: Use logging category
  * AlternativesModel: Drop unused header
  * tests: Rework testing share tool
  * tests: Set initial properties instead of introspecting objects later
  * tests: Correctly check for additional positional arguments
  * tests: Remove duplicating calls to add help and version CLI options
  * tests: Add missing translation domain
  * Drop QML import versions
  * Fix some QML and C++ code style
  * Use ellipses instead of triple period
  * AlternativesModel: Use correct role for a tooltip
  * kdeconnect: Don't let the Heading overflow
  * Namespace embedded resources
  * support USE_DBUS option to enable/disable dbus use
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Remove explicit maintainer from metainfo
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Add pre share hooks
  * Enforce passing tests on Windows
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
* Sat Mar  9 2024 Christophe Marin <christophe@krop.fr>
- Move the purpose service files to a subpackage
* Fri Mar  8 2024 Christophe Marin <christophe@krop.fr>
- Enable the kaccounts integration
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
- Drop patches, now upstream:
  * 0001-Don-t-install-internal-static-library.patch
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
- Add patch to avoid unneeded static lib:
  * 0001-Don-t-install-internal-static-library.patch
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-purpose
